;**************************************************************************
;* FileName	: RS232_HW.INC
;* Date 	: 07.06.2005
;* File version : v1.00
;*
;* Author	: MIKO, Imre
;*                VIDA, Istvan Tamas
;* Company	:
;* Homepage	: http://majki.fw.hu
;* E-mail	: majki@fw.hu, 3218811@t-email.hu
;*
;*-------------------------------------------------------------------------
;*
;* Description	: functions for for rs485 communication
;*		  =====================================
;*		  RS232_SendByte
;*		  RS232_ReceiveByte
;*		  RS232_SendCS
;*
;*
;*-------------------------------------------------------------------------
;* Needed defines and includes in main-modul:
;* 
;* #define	RS232_TxD	PORTB,2		; in
;* #define	RS232_RxD	PORTB,1		; out
;*
;*-------------------------------------------------------------------------
;* Other possible defines in main-modul:
;*
;*
;* #define DEBUG			; for some debug message
;* #define NO_RS232			; for fast simulation
;*
;**************************************************************************
;* Revision History:
;*
;* 1.00	  30/12/2003 	Initial Release
;*
;**************************************************************************

;***** VARIABLES **********************************************************

	ifdef INC_RS232_SCS
		cblock
		  RS232_temp
		endc
	endif



;***** SEND SERIAL DATA ***************************************************
;* Send byte
;* Input : W				; byte
;* Output: -
;* Clock : ?
;**************************************************************************
RS232_SendByte
RS232_waittx	btfss	PIR1, TXIF		; wait for empty buffer
	        goto	RS232_waittx
		movwf	TXREG
		return



;***** RECEIVE SERIAL DATA ************************************************
;* Receive byte
;* Input : -				; 
;* Output: received byte -> W		;
;*	   staus -> Z			; 1 = ok (jz), 0 = error or dont received (jnz)
;* Clock : ?
;**************************************************************************
RS232_ReceiveByte
		btfss	PIR1, RCIF
		goto	RS232_norec
		movlw	((1 << OERR) | (1 << FERR))	; serial receive error
		andwf	RCSTA,w
		jz	RS232_rb_no_error
		movf	RCREG,w				; read received byte twice for deletion
		movf	RCREG,w
		btfsc	RCSTA, OERR			; if OERR
		bcf	RCSTA, CREN			;    - clear CREN and 
		bsf	RCSTA, CREN			;    - and set again.
RS232_norec	clrw
		clrz					; Z=0 -> error or dont received
   		return

RS232_rb_no_error 
		movf	RCREG,w
	        setz					; Z=1 -> ok
		return



;***** RS232_SendCS *******************************************************
;* Send constant string
;* Input : -				; 
;* Output: received byte -> W		;
;* Clock : ?
;**************************************************************************
ifdef INC_RS232_SCS
RS232_SendCS	  
		movwf	PCLATH
RS232_sendcs1	call	RS232_sendcs_getc
                testw
                skipnz
		return

		call	RS232_SendByte
		incf	RS232_temp,f
		skipnz
		incf	PCLATH,f
		goto	RS232_sendcs1

RS232_sendcs_getc 
		movf	RS232_temp,w
		movwf	PCL		; computed goto!
endif

;**************************************************************************



